@@ -10,8 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import datetime
-
 import testtools
 
 from openstack.network.v2 import subnet
@@ -35,6 +33,7 @@ EXAMPLE = {
     'description': '13',
     'created_at': '2016-03-09T12:14:57.233772',
     'updated_at': '2016-07-09T12:14:57.233772',
+    'segment_id': '16',
 }
 
 
@@ -69,9 +68,6 @@ class TestSubnet(testtools.TestCase):
         self.assertEqual(EXAMPLE['tenant_id'], sot.project_id)
         self.assertEqual(EXAMPLE['subnetpool_id'], sot.subnet_pool_id)
         self.assertEqual(EXAMPLE['description'], sot.description)
-        dt = datetime.datetime(2016, 3, 9, 12, 14, 57, 233772).replace(
-            tzinfo=None)
-        self.assertEqual(dt, sot.created_at.replace(tzinfo=None))
-        dt = datetime.datetime(2016, 7, 9, 12, 14, 57, 233772).replace(
-            tzinfo=None)
-        self.assertEqual(dt, sot.updated_at.replace(tzinfo=None))
+        self.assertEqual(EXAMPLE['created_at'], sot.created_at)
+        self.assertEqual(EXAMPLE['updated_at'], sot.updated_at)
+        self.assertEqual(EXAMPLE['segment_id'], sot.segment_id)
